urlocal.impl.cache

This namespace is not part of the public API of urlocal and may change without notice.

This namespace is not part of the public API of urlocal and may change
without notice.
raw docstring

urlocal.impl.xdg

Vars related to the XDG Base Directory Specification: https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html This namespace is not part of the public API of urlocal and may change without notice.

Vars related to the XDG Base Directory Specification: https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html
This namespace is not part of the public API of urlocal and may change without
notice.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries