Vars related to the XDG Base Directory Specification: https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html This namespace is not part of the public API of urlocal and may change without notice.
Vars related to the XDG Base Directory Specification: https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html This namespace is not part of the public API of urlocal and may change without notice.
The base location of the XDG 'cache home' directory, as per the specification. Does not include include any application-specific sub-directories, and always ends with a path separator character.
The base location of the XDG 'cache home' directory, as per the specification. Does not include include any application-specific sub-directories, and always ends with a path separator character.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |