This namespace is not part of the public API of urlocal and may change without notice.
This namespace is not part of the public API of urlocal and may change without notice.
Vars related to the XDG Base Directory Specification: https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html This namespace is not part of the public API of urlocal and may change without notice.
Vars related to the XDG Base Directory Specification: https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html This namespace is not part of the public API of urlocal and may change without notice.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |